You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commons-dev@ws.apache.org by ve...@apache.org on 2009/03/03 21:13:16 UTC

svn commit: r749721 - in /webservices/commons/trunk/modules/axiom/modules: axiom-api/src/main/java/org/apache/axiom/om/ axiom-api/src/test/java/org/apache/axiom/om/ axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/ axiom-dom/src/test/java/o...

Author: veithen
Date: Tue Mar  3 20:13:14 2009
New Revision: 749721

URL: http://svn.apache.org/viewvc?rev=749721&view=rev
Log:
Renamed OMImplementation to OMMetaFactory and converted it from an abstract class to an interface. This will be useful for OSGIification (OSGi will require an interface here). Eliminating OMImplementation is OK because
- it only exists in the 1.2.8 release;
- it was not yet complete (no getInstance method);
- it was only used in the test cases;
- we can easily put it back if somebody complains.

Added:
    webservices/commons/trunk/modules/axiom/modules/axiom-api/src/main/java/org/apache/axiom/om/OMMetaFactory.java
      - copied, changed from r749710, webservices/commons/trunk/modules/axiom/modules/axiom-api/src/main/java/org/apache/axiom/om/OMImplementation.java
    webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/OMDOMMetaFactory.java
      - copied, changed from r749710, webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/OMDOMImplementation.java
    webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/main/java/org/apache/axiom/om/impl/llom/factory/OMLinkedListMetaFactory.java
      - copied, changed from r749710, webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/main/java/org/apache/axiom/om/impl/llom/factory/OMLinkedListImplementation.java
Removed:
    webservices/commons/trunk/modules/axiom/modules/axiom-api/src/main/java/org/apache/axiom/om/OMImplementation.java
    webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/OMDOMImplementation.java
    webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/main/java/org/apache/axiom/om/impl/llom/factory/OMLinkedListImplementation.java
Modified:
    webservices/commons/trunk/modules/axiom/modules/axiom-api/src/test/java/org/apache/axiom/om/OMAttributeTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-api/src/test/java/org/apache/axiom/om/OMDocumentTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/AttributeTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/DocumentImplTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/test/java/org/apache/axiom/om/impl/llom/AttributeImplTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/test/java/org/apache/axiom/om/impl/llom/OMDocumentImplTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPBodyTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPBodyTestCase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPDiscardTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPEnvelopeTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultCodeTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultCodeTestCase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultDetailTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultNodeTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultReasonTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultReasonTestCase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultRoleTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultSubCodeTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultSubCodeTestCase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTestCase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTextTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultValueTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderBlockTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderTestBase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderTestCase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPTestCase.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPBodyTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPEnvelopeTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultCodeTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultDetailTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultReasonTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultRoleTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultSubCodeTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultTextTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultValueTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPHeaderTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPBodyTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPDiscardTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPEnvelopeTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultCodeTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultDetailTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultNodeTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultReasonTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultRoleTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultSubCodeTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultTextTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultValueTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPHeaderBlockTest.java
    webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPHeaderTest.java

Copied: webservices/commons/trunk/modules/axiom/modules/axiom-api/src/main/java/org/apache/axiom/om/OMMetaFactory.java (from r749710, webservices/commons/trunk/modules/axiom/modules/axiom-api/src/main/java/org/apache/axiom/om/OMImplementation.java)
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-api/src/main/java/org/apache/axiom/om/OMMetaFactory.java?p2=webservices/commons/trunk/modules/axiom/modules/axiom-api/src/main/java/org/apache/axiom/om/OMMetaFactory.java&p1=webservices/commons/trunk/modules/axiom/modules/axiom-api/src/main/java/org/apache/axiom/om/OMImplementation.java&r1=749710&r2=749721&rev=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-api/src/test/java/org/apache/axiom/om/OMAttributeTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-api/src/test/java/org/apache/axiom/om/OMAttributeTestBase.java Tue Mar  3 20:13:14 2009
@@ -24,10 +24,10 @@
 import junit.framework.TestCase;
 
 public class OMAttributeTestBase extends TestCase {
-    private final OMImplementation omImplementation;
+    private final OMMetaFactory omMetaFactory;
 
-    public OMAttributeTestBase(OMImplementation omImplementation) {
-        this.omImplementation = omImplementation;
+    public OMAttributeTestBase(OMMetaFactory omMetaFactory) {
+        this.omMetaFactory = omMetaFactory;
     }
     
     /**
@@ -37,7 +37,7 @@
     public void testQNames() throws Exception {
         String ATTR = "attr";
         String NSURI = "http://ns1";
-        OMFactory fac = omImplementation.getOMFactory();
+        OMFactory fac = omMetaFactory.getOMFactory();
         OMNamespace ns = fac.createOMNamespace(NSURI, null);
         OMAttribute attr = fac.createOMAttribute(ATTR, ns, "value");
         QName qname = attr.getQName();

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-api/src/test/java/org/apache/axiom/om/OMDocumentTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-api/src/test/java/org/apache/axiom/om/OMDocumentTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-api/src/test/java/org/apache/axiom/om/OMDocumentTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-api/src/test/java/org/apache/axiom/om/OMDocumentTestBase.java Tue Mar  3 20:13:14 2009
@@ -37,10 +37,10 @@
             "    <ProjectName>The Apache Web Sevices Project</ProjectName>" +
             "</Axis2>";
     
-    private final OMImplementation omImplementation;
+    private final OMMetaFactory omMetaFactory;
     
-    public OMDocumentTestBase(OMImplementation omImplementation) {
-        this.omImplementation = omImplementation;
+    public OMDocumentTestBase(OMMetaFactory omMetaFactory) {
+        this.omMetaFactory = omMetaFactory;
     }
 
     public void testParse() {
@@ -98,7 +98,7 @@
             XMLStreamReader xmlStreamReader =
                     XMLInputFactory.newInstance().createXMLStreamReader(new StringReader(xml));
             StAXOMBuilder builder =
-                    new StAXOMBuilder(omImplementation.getOMFactory(), xmlStreamReader);
+                    new StAXOMBuilder(omMetaFactory.getOMFactory(), xmlStreamReader);
             return builder.getDocument();
         } catch (XMLStreamException e) {
             throw new UnsupportedOperationException();

Copied: webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/OMDOMMetaFactory.java (from r749710, webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/OMDOMImplementation.java)
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/OMDOMMetaFactory.java?p2=webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/OMDOMMetaFactory.java&p1=webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/OMDOMImplementation.java&r1=749710&r2=749721&rev=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/OMDOMImplementation.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/main/java/org/apache/axiom/om/impl/dom/factory/OMDOMMetaFactory.java Tue Mar  3 20:13:14 2009
@@ -20,7 +20,7 @@
 package org.apache.axiom.om.impl.dom.factory;
 
 import org.apache.axiom.om.OMFactory;
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 import org.apache.axiom.soap.SOAPFactory;
 import org.apache.axiom.soap.impl.dom.soap11.SOAP11Factory;
 import org.apache.axiom.soap.impl.dom.soap12.SOAP12Factory;
@@ -32,7 +32,7 @@
  * Therefore {@link #getOMFactory()}, {@link #getSOAP11Factory()} and
  * {@link #getSOAP12Factory()} will return a new instance on every invocation.
  */
-public class OMDOMImplementation extends OMImplementation {
+public class OMDOMMetaFactory implements OMMetaFactory {
     public OMFactory getOMFactory() {
         return new OMDOMFactory();
     }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/AttributeTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/AttributeTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/AttributeTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/AttributeTest.java Tue Mar  3 20:13:14 2009
@@ -20,10 +20,10 @@
 package org.apache.axiom.om.impl.dom;
 
 import org.apache.axiom.om.OMAttributeTestBase;
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 
 public class AttributeTest extends OMAttributeTestBase {
     public AttributeTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/DocumentImplTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/DocumentImplTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/DocumentImplTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/DocumentImplTest.java Tue Mar  3 20:13:14 2009
@@ -23,7 +23,7 @@
 import javax.xml.stream.XMLStreamException;
 
 import org.apache.axiom.om.OMDocumentTestBase;
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.w3c.dom.Attr;
 import org.w3c.dom.DOMException;
 import org.w3c.dom.Document;
@@ -33,7 +33,7 @@
 
 public class DocumentImplTest extends OMDocumentTestBase {
     public DocumentImplTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 
     public void testCreateElement() throws Exception {

Copied: webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/main/java/org/apache/axiom/om/impl/llom/factory/OMLinkedListMetaFactory.java (from r749710, webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/main/java/org/apache/axiom/om/impl/llom/factory/OMLinkedListImplementation.java)
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/main/java/org/apache/axiom/om/impl/llom/factory/OMLinkedListMetaFactory.java?p2=webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/main/java/org/apache/axiom/om/impl/llom/factory/OMLinkedListMetaFactory.java&p1=webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/main/java/org/apache/axiom/om/impl/llom/factory/OMLinkedListImplementation.java&r1=749710&r2=749721&rev=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/main/java/org/apache/axiom/om/impl/llom/factory/OMLinkedListImplementation.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/main/java/org/apache/axiom/om/impl/llom/factory/OMLinkedListMetaFactory.java Tue Mar  3 20:13:14 2009
@@ -20,7 +20,7 @@
 package org.apache.axiom.om.impl.llom.factory;
 
 import org.apache.axiom.om.OMFactory;
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 import org.apache.axiom.soap.SOAPFactory;
 import org.apache.axiom.soap.impl.llom.soap11.SOAP11Factory;
 import org.apache.axiom.soap.impl.llom.soap12.SOAP12Factory;
@@ -32,7 +32,7 @@
  * {@link #getSOAP11Factory()} and {@link #getSOAP12Factory()} will return the
  * same instance on every invocation.
  */
-public class OMLinkedListImplementation extends OMImplementation {
+public class OMLinkedListMetaFactory implements OMMetaFactory {
     private final OMFactory omFactory = new OMLinkedListImplFactory();
     private final SOAPFactory soap11Factory = new SOAP11Factory();
     private final SOAPFactory soap12Factory = new SOAP12Factory();

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/test/java/org/apache/axiom/om/impl/llom/AttributeImplTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/test/java/org/apache/axiom/om/impl/llom/AttributeImplTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/test/java/org/apache/axiom/om/impl/llom/AttributeImplTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/test/java/org/apache/axiom/om/impl/llom/AttributeImplTest.java Tue Mar  3 20:13:14 2009
@@ -20,11 +20,11 @@
 package org.apache.axiom.om.impl.llom;
 
 import org.apache.axiom.om.OMAttributeTestBase;
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 
 public class AttributeImplTest extends OMAttributeTestBase {
     public AttributeImplTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
     
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/test/java/org/apache/axiom/om/impl/llom/OMDocumentImplTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/test/java/org/apache/axiom/om/impl/llom/OMDocumentImplTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/test/java/org/apache/axiom/om/impl/llom/OMDocumentImplTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-impl/src/test/java/org/apache/axiom/om/impl/llom/OMDocumentImplTest.java Tue Mar  3 20:13:14 2009
@@ -20,10 +20,10 @@
 package org.apache.axiom.om.impl.llom;
 
 import org.apache.axiom.om.OMDocumentTestBase;
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 
 public class OMDocumentImplTest extends OMDocumentTestBase {
     public OMDocumentImplTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPBodyTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPBodyTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPBodyTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPBodyTestBase.java Tue Mar  3 20:13:14 2009
@@ -19,12 +19,12 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public class SOAPBodyTestBase extends SOAPBodyTestCase {
 
-    public SOAPBodyTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPBodyTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     //SOAP 1.1 Body Test (Programaticaly created)----------------------------------------------------------------------------------

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPBodyTestCase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPBodyTestCase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPBodyTestCase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPBodyTestCase.java Tue Mar  3 20:13:14 2009
@@ -19,7 +19,7 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public abstract class SOAPBodyTestCase extends SOAPTestCase {
     protected SOAPBody soap11Body;
@@ -28,8 +28,8 @@
     protected SOAPBody soap11BodyWithParser;
     protected SOAPBody soap12BodyWithParser;
 
-    public SOAPBodyTestCase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPBodyTestCase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
 
     }
 

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPDiscardTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPDiscardTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPDiscardTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPDiscardTestBase.java Tue Mar  3 20:13:14 2009
@@ -20,7 +20,7 @@
 
 import javax.xml.stream.XMLStreamException;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 /**
  * @author : Ajith Ranabahu
@@ -30,8 +30,8 @@
 public class SOAPDiscardTestBase  extends SOAPTestCase{
 
 
-    public SOAPDiscardTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPDiscardTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     public void testDiscardHeader(){

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPEnvelopeTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPEnvelopeTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPEnvelopeTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPEnvelopeTestBase.java Tue Mar  3 20:13:14 2009
@@ -20,17 +20,17 @@
 package org.apache.axiom.soap;
 
 import org.apache.axiom.om.OMAbstractFactory;
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 
 public class SOAPEnvelopeTestBase extends SOAPTestCase {
     protected SOAPEnvelope soap11Envelope;
     protected SOAPEnvelope soap12Envelope;
 
-    public SOAPEnvelopeTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
-        soap11Envelope = omImplementation.getSOAP11Factory().getDefaultEnvelope();
-        soap12Envelope = omImplementation.getSOAP12Factory().getDefaultEnvelope();
+    public SOAPEnvelopeTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
+        soap11Envelope = omMetaFactory.getSOAP11Factory().getDefaultEnvelope();
+        soap12Envelope = omMetaFactory.getSOAP12Factory().getDefaultEnvelope();
     }
 
     //SOAP 1.1 Envelope Test (Programaticaly Created)-----------------------------------------------

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultCodeTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultCodeTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultCodeTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultCodeTestBase.java Tue Mar  3 20:13:14 2009
@@ -19,13 +19,13 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 
 public class SOAPFaultCodeTestBase extends SOAPFaultCodeTestCase {
 
-    public SOAPFaultCodeTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultCodeTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     //SOAP 1.1 Fault Code Test (Programaticaly Created)

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultCodeTestCase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultCodeTestCase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultCodeTestCase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultCodeTestCase.java Tue Mar  3 20:13:14 2009
@@ -19,7 +19,7 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public abstract class SOAPFaultCodeTestCase extends SOAPFaultTestCase {
 
@@ -29,8 +29,8 @@
     protected SOAPFaultCode soap11FaultCodeWithParser;
     protected SOAPFaultCode soap12FaultCodeWithParser;
 
-    public SOAPFaultCodeTestCase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultCodeTestCase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     protected void setUp() throws Exception {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultDetailTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultDetailTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultDetailTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultDetailTestBase.java Tue Mar  3 20:13:14 2009
@@ -21,7 +21,7 @@
 
 import org.apache.axiom.om.OMAbstractFactory;
 import org.apache.axiom.om.OMElement;
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 import org.apache.axiom.om.OMNamespace;
 import org.apache.axiom.om.OMText;
 
@@ -34,8 +34,8 @@
     protected SOAPFaultDetail soap12FaultDetailWithParser;
     protected OMNamespace omNamespace;
 
-    public SOAPFaultDetailTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultDetailTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
         omNamespace =
                 omFactory.createOMNamespace("http://www.test.org", "test");
     }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultNodeTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultNodeTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultNodeTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultNodeTestBase.java Tue Mar  3 20:13:14 2009
@@ -19,14 +19,14 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public class SOAPFaultNodeTestBase extends SOAPFaultTestCase {
     protected SOAPFaultNode soap12FaultNode;
     protected SOAPFaultNode soap12FaultNodeWithParser;
 
-    public SOAPFaultNodeTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultNodeTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     protected void setUp() throws Exception {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultReasonTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultReasonTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultReasonTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultReasonTestBase.java Tue Mar  3 20:13:14 2009
@@ -19,12 +19,12 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public class SOAPFaultReasonTestBase extends SOAPFaultReasonTestCase {
 
-    public SOAPFaultReasonTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultReasonTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     //SOAP 1.1 Fault Reason Test (Programaticaly Created)

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultReasonTestCase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultReasonTestCase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultReasonTestCase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultReasonTestCase.java Tue Mar  3 20:13:14 2009
@@ -19,7 +19,7 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public abstract class SOAPFaultReasonTestCase extends SOAPFaultTestCase {
 
@@ -28,8 +28,8 @@
     protected SOAPFaultReason soap11FaultReasonWithParser;
     protected SOAPFaultReason soap12FaultReasonWithParser;
 
-    public SOAPFaultReasonTestCase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultReasonTestCase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     protected void setUp() throws Exception {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultRoleTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultRoleTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultRoleTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultRoleTestBase.java Tue Mar  3 20:13:14 2009
@@ -19,7 +19,7 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public class SOAPFaultRoleTestBase extends SOAPFaultTestCase {
 
@@ -28,8 +28,8 @@
     protected SOAPFaultRole soap11FaultRoleWithParser;
     protected SOAPFaultRole soap12FaultRoleWithParser;
 
-    public SOAPFaultRoleTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultRoleTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     protected void setUp() throws Exception {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultSubCodeTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultSubCodeTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultSubCodeTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultSubCodeTestBase.java Tue Mar  3 20:13:14 2009
@@ -19,13 +19,13 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 
 public class SOAPFaultSubCodeTestBase extends SOAPFaultSubCodeTestCase {
 
-    public SOAPFaultSubCodeTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultSubCodeTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     //SOAP Fault SubCode(In Fault Code) Test (Programaticaly Created)

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultSubCodeTestCase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultSubCodeTestCase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultSubCodeTestCase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultSubCodeTestCase.java Tue Mar  3 20:13:14 2009
@@ -19,7 +19,7 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public abstract class SOAPFaultSubCodeTestCase extends SOAPFaultCodeTestCase {
     protected SOAPFaultValue soap11FaultValue;
@@ -36,8 +36,8 @@
     protected SOAPFaultValue soap12FaultValueInFaultSubCodeWithParser;
     protected SOAPFaultSubCode soap12FaultSubCodeInSubCodeWithParser;
 
-    public SOAPFaultSubCodeTestCase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultSubCodeTestCase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     protected void setUp() throws Exception {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTestBase.java Tue Mar  3 20:13:14 2009
@@ -20,12 +20,12 @@
 package org.apache.axiom.soap;
 
 import org.apache.axiom.om.OMAbstractFactory;
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public class SOAPFaultTestBase extends SOAPFaultTestCase {
 
-    public SOAPFaultTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     //SOAP 1.1 Fault Test (Programaticaly created)-----------------------------------------------------------------------------------

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTestCase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTestCase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTestCase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTestCase.java Tue Mar  3 20:13:14 2009
@@ -19,7 +19,7 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public abstract class SOAPFaultTestCase extends SOAPBodyTestCase {
     protected SOAPFault soap11Fault;
@@ -27,8 +27,8 @@
     protected SOAPFault soap11FaultWithParser;
     protected SOAPFault soap12FaultWithParser;
 
-    public SOAPFaultTestCase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultTestCase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     protected void setUp() throws Exception {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTextTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTextTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTextTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultTextTestBase.java Tue Mar  3 20:13:14 2009
@@ -20,7 +20,7 @@
 package org.apache.axiom.soap;
 
 import org.apache.axiom.om.OMAttribute;
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public class SOAPFaultTextTestBase extends SOAPFaultReasonTestCase {
     protected SOAPFaultText soap11FaultText;
@@ -28,8 +28,8 @@
     protected String soap11FaultTextWithParser;
     protected SOAPFaultText soap12FaultTextWithParser;
 
-    public SOAPFaultTextTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultTextTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     protected void setUp() throws Exception {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultValueTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultValueTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultValueTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPFaultValueTestBase.java Tue Mar  3 20:13:14 2009
@@ -19,12 +19,12 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public class SOAPFaultValueTestBase extends SOAPFaultSubCodeTestCase {
 
-    public SOAPFaultValueTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPFaultValueTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     protected void setUp() throws Exception {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderBlockTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderBlockTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderBlockTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderBlockTestBase.java Tue Mar  3 20:13:14 2009
@@ -19,7 +19,7 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 import org.apache.axiom.om.OMNamespace;
 
 import java.util.Iterator;
@@ -34,8 +34,8 @@
     protected SOAPHeaderBlock soap11HeaderBlock3WithParser;
     protected SOAPHeaderBlock soap12HeaderBlock3WithParser;
 
-    public SOAPHeaderBlockTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPHeaderBlockTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     protected void setUp() throws Exception {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderTestBase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderTestBase.java Tue Mar  3 20:13:14 2009
@@ -22,13 +22,13 @@
 import java.util.ArrayList;
 import java.util.Iterator;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 
 public class SOAPHeaderTestBase extends SOAPHeaderTestCase {
     private static final String ROLE_URI = "http://schemas.xmlsoap.org/soap/envelope/actor/next";
 
-    public SOAPHeaderTestBase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPHeaderTestBase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
     }
 
     //SOAP 1.1 Header Test (Programaticaly Created)--------------------------------------------------------------------------------

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderTestCase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderTestCase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderTestCase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPHeaderTestCase.java Tue Mar  3 20:13:14 2009
@@ -19,7 +19,7 @@
 
 package org.apache.axiom.soap;
 
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 import org.apache.axiom.om.OMNamespace;
 
 public abstract class SOAPHeaderTestCase extends SOAPTestCase {
@@ -29,8 +29,8 @@
     protected SOAPHeader soap12HeaderWithParser;
     protected OMNamespace namespace;
 
-    public SOAPHeaderTestCase(OMImplementation omImplementation) {
-        super(omImplementation);
+    public SOAPHeaderTestCase(OMMetaFactory omMetaFactory) {
+        super(omMetaFactory);
         namespace =
                 omFactory.createOMNamespace("http://www.example.org", "test");
     }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPTestCase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPTestCase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPTestCase.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/SOAPTestCase.java Tue Mar  3 20:13:14 2009
@@ -21,7 +21,7 @@
 
 import org.apache.axiom.om.AbstractTestCase;
 import org.apache.axiom.om.OMFactory;
-import org.apache.axiom.om.OMImplementation;
+import org.apache.axiom.om.OMMetaFactory;
 import org.apache.axiom.soap.impl.builder.StAXSOAPModelBuilder;
 
 import javax.xml.stream.XMLInputFactory;
@@ -41,10 +41,10 @@
     protected static final String SOAP11_FILE_NAME = "soap/soap11/soap11message.xml";
     protected static final String SOAP12_FILE_NAME = "soap/soap12message.xml";
 
-    public SOAPTestCase(OMImplementation omImplementation) {
-        soap11Factory = omImplementation.getSOAP11Factory();
-        soap12Factory = omImplementation.getSOAP12Factory();
-        omFactory = omImplementation.getOMFactory();
+    public SOAPTestCase(OMMetaFactory omMetaFactory) {
+        soap11Factory = omMetaFactory.getSOAP11Factory();
+        soap12Factory = omMetaFactory.getSOAP12Factory();
+        omFactory = omMetaFactory.getOMFactory();
     }
 
     protected void setUp() throws Exception {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPBodyTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPBodyTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPBodyTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPBodyTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPBodyTestBase;
 
 public class SOAPBodyTest extends SOAPBodyTestBase {
     public SOAPBodyTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPEnvelopeTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPEnvelopeTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPEnvelopeTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPEnvelopeTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPEnvelopeTestBase;
 
 public class SOAPEnvelopeTest extends SOAPEnvelopeTestBase {
     public SOAPEnvelopeTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultCodeTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultCodeTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultCodeTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultCodeTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPFaultCodeTestBase;
 
 public class SOAPFaultCodeTest extends SOAPFaultCodeTestBase {
     public SOAPFaultCodeTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultDetailTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultDetailTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultDetailTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultDetailTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPFaultDetailTestBase;
 
 public class SOAPFaultDetailTest extends SOAPFaultDetailTestBase {
     public SOAPFaultDetailTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultReasonTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultReasonTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultReasonTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultReasonTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPFaultReasonTestBase;
 
 public class SOAPFaultReasonTest extends SOAPFaultReasonTestBase {
     public SOAPFaultReasonTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultRoleTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultRoleTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultRoleTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultRoleTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPFaultRoleTestBase;
 
 public class SOAPFaultRoleTest extends SOAPFaultRoleTestBase {
     public SOAPFaultRoleTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultSubCodeTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultSubCodeTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultSubCodeTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultSubCodeTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPFaultSubCodeTestBase;
 
 public class SOAPFaultSubCodeTest extends SOAPFaultSubCodeTestBase {
     public SOAPFaultSubCodeTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPFaultTestBase;
 
 public class SOAPFaultTest extends SOAPFaultTestBase {
     public SOAPFaultTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultTextTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultTextTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultTextTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultTextTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPFaultTextTestBase;
 
 public class SOAPFaultTextTest extends SOAPFaultTextTestBase {
     public SOAPFaultTextTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultValueTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultValueTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultValueTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPFaultValueTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPFaultValueTestBase;
 
 public class SOAPFaultValueTest extends SOAPFaultValueTestBase {
     public SOAPFaultValueTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPHeaderTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPHeaderTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPHeaderTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/dom/SOAPHeaderTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.dom;
 
-import org.apache.axiom.om.impl.dom.factory.OMDOMImplementation;
+import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
 import org.apache.axiom.soap.SOAPHeaderTestBase;
 
 public class SOAPHeaderTest extends SOAPHeaderTestBase {
     public SOAPHeaderTest() {
-        super(new OMDOMImplementation());
+        super(new OMDOMMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPBodyTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPBodyTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPBodyTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPBodyTest.java Tue Mar  3 20:13:14 2009
@@ -20,12 +20,12 @@
 package org.apache.axiom.soap.impl.llom;
 
 import org.apache.axiom.om.OMException;
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPBodyTestBase;
 
 public class SOAPBodyTest extends SOAPBodyTestBase {
     public SOAPBodyTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 
     public void testSOAPBodyDetachment() {

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPDiscardTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPDiscardTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPDiscardTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPDiscardTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPDiscardTestBase;
 
 public class SOAPDiscardTest extends SOAPDiscardTestBase {
     public SOAPDiscardTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPEnvelopeTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPEnvelopeTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPEnvelopeTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPEnvelopeTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPEnvelopeTestBase;
 
 public class SOAPEnvelopeTest extends SOAPEnvelopeTestBase {
     public SOAPEnvelopeTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultCodeTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultCodeTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultCodeTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultCodeTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPFaultCodeTestBase;
 
 public class SOAPFaultCodeTest extends SOAPFaultCodeTestBase {
     public SOAPFaultCodeTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultDetailTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultDetailTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultDetailTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultDetailTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPFaultDetailTestBase;
 
 public class SOAPFaultDetailTest extends SOAPFaultDetailTestBase {
     public SOAPFaultDetailTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultNodeTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultNodeTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultNodeTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultNodeTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPFaultNodeTestBase;
 
 public class SOAPFaultNodeTest extends SOAPFaultNodeTestBase {
     public SOAPFaultNodeTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultReasonTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultReasonTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultReasonTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultReasonTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPFaultReasonTestBase;
 
 public class SOAPFaultReasonTest extends SOAPFaultReasonTestBase {
     public SOAPFaultReasonTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultRoleTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultRoleTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultRoleTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultRoleTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPFaultRoleTestBase;
 
 public class SOAPFaultRoleTest extends SOAPFaultRoleTestBase {
     public SOAPFaultRoleTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultSubCodeTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultSubCodeTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultSubCodeTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultSubCodeTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPFaultSubCodeTestBase;
 
 public class SOAPFaultSubCodeTest extends SOAPFaultSubCodeTestBase {
     public SOAPFaultSubCodeTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPFaultTestBase;
 
 public class SOAPFaultTest extends SOAPFaultTestBase {
     public SOAPFaultTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultTextTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultTextTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultTextTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultTextTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPFaultTextTestBase;
 
 public class SOAPFaultTextTest extends SOAPFaultTextTestBase {
     public SOAPFaultTextTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultValueTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultValueTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultValueTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPFaultValueTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPFaultValueTestBase;
 
 public class SOAPFaultValueTest extends SOAPFaultValueTestBase {
     public SOAPFaultValueTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPHeaderBlockTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPHeaderBlockTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPHeaderBlockTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPHeaderBlockTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPHeaderBlockTestBase;
 
 public class SOAPHeaderBlockTest extends SOAPHeaderBlockTestBase {
     public SOAPHeaderBlockTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPHeaderTest.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPHeaderTest.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================
--- webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPHeaderTest.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-tests/src/test/java/org/apache/axiom/soap/impl/llom/SOAPHeaderTest.java Tue Mar  3 20:13:14 2009
@@ -19,11 +19,11 @@
 
 package org.apache.axiom.soap.impl.llom;
 
-import org.apache.axiom.om.impl.llom.factory.OMLinkedListImplementation;
+import org.apache.axiom.om.impl.llom.factory.OMLinkedListMetaFactory;
 import org.apache.axiom.soap.SOAPHeaderTestBase;
 
 public class SOAPHeaderTest extends SOAPHeaderTestBase {
     public SOAPHeaderTest() {
-        super(new OMLinkedListImplementation());
+        super(new OMLinkedListMetaFactory());
     }
 }
--- webservices/commons/trunk/modules/axiom/modules/axiom-api/src/main/java/org/apache/axiom/om/OMImplementation.java (original)
+++ webservices/commons/trunk/modules/axiom/modules/axiom-api/src/main/java/org/apache/axiom/om/OMMetaFactory.java Tue Mar  3 20:13:14 2009
@@ -22,7 +22,7 @@
 import org.apache.axiom.soap.SOAPFactory;
 
 /**
  * Abstract class encapsulating a particular object model.
  * It provides instances for plain XML, SOAP 1.1 and SOAP 1.2 object model factories for the
  * given object model implementation. Currently the two OM implementations provided by
  * Axiom are LLOM (linked list) and DOM.
@@ -37,25 +37,25 @@
  */
 // NOTE: It is intentional that this is implemented as an abstract class rather than an interface.
 //       Probably there will be a static getInstance() method in the future.
-public abstract class OMImplementation {
+public interface OMMetaFactory {
     /**
      * Get an OM factory instance for the XML infoset model.
      *
      * @return the OM factory instance
      */
-    public abstract OMFactory getOMFactory();
+    OMFactory getOMFactory();
     
     /**
      * Get an OM factory instance for the SOAP 1.1 infoset model.
      *
      * @return the OM factory instance
      */
-    public abstract SOAPFactory getSOAP11Factory();
+    SOAPFactory getSOAP11Factory();
     
     /**
      * Get an OM factory instance for the SOAP 1.2 infoset model.
      *
      * @return the OM factory instance
      */
-    public abstract SOAPFactory getSOAP12Factory();
+    SOAPFactory getSOAP12Factory();
 }
@@ -22,7 +22,7 @@
 
 /**
- * Abstract class encapsulating a particular object model.
+ * Interface encapsulating a particular object model.
  * It provides instances for plain XML, SOAP 1.1 and SOAP 1.2 object model factories for the
  * given object model implementation. Currently the two OM implementations provided by

Modified: webservices/commons/trunk/modules/axiom/modules/axiom-api/src/test/java/org/apache/axiom/om/OMAttributeTestBase.java
URL: http://svn.apache.org/viewvc/webservices/commons/trunk/modules/axiom/modules/axiom-api/src/test/java/org/apache/axiom/om/OMAttributeTestBase.java?rev=749721&r1=749720&r2=749721&view=diff
==============================================================================